/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 *            Gianmarco Brocchi <brocchi@poisson.phc.unipi.it>
 */

using Gtk;

namespace Clinica {

    public class DoctorListPage : HBox, Page {
        
        private Alignment sidebar;
        private DoctorListView view;
        private VBox left_vbox;
        private ScrolledWindow scrolled_window;
        
        /**
         * @brief Page with the list of doctors. 
         */
        public class DoctorListPage () {
		    GLib.Object (homogeneous: false, spacing: 5);
            connect_signal ();
            
            var builder = new Builder ();
            
            try {
                builder.add_from_file (Application.resources.get_ui_file ("doctor_list_toolbar.glade"));
                builder.add_from_file (Application.resources.get_ui_file ("doctor_list_sidebar.glade"));
            } catch (Error e) {
                error ("Error loading doctor_list_toolbar.glade. Check your installation.");
            }
            
            left_vbox = builder.get_object ("left_vbox") as VBox;
            sidebar = builder.get_object ("sidebar") as Alignment;
            scrolled_window = builder.get_object ("treeview_scrolled_window") as ScrolledWindow;
            
            /* Get find_entry to filter the doctors */
            var find_entry = builder.get_object ("find_entry") as Entry;
            view = new DoctorListView (find_entry);
            scrolled_window.add (view);
            
            pack_start (left_vbox, true, true, 5);
            pack_start (sidebar, false, true, 5);
            view.show ();
            
            builder.connect_signals (this);
        }
        
        public void setup () {
            new_title (_("Doctors"));
        }
        
        [CCode (instance_pos = -1)]
        public void on_add_button_clicked (Button button) {
        	var new_doc_dialog = new DoctorEditor ();
        	new_doc_dialog.run ();
			new_doc_dialog.destroy ();
        }
        
        [CCode (instance_pos = -1)]
        public void on_back_button_clicked (Button button) {
            start_page_requested ();
        }
        
        [CCode (instance_pos = -1)]
        public void on_modify_button_clicked (Button button) {
        	Doctor? doc = view.get_selected_doctor ();
        	if (doc == null)
        		return;
        	var edit_doc_dialog = new DoctorEditor.with_doctor (doc);
        	edit_doc_dialog.run ();
        	edit_doc_dialog.destroy ();
        }
        
        /**
         * @brief Callback called when a user try to delete a doctor
         * clicking on the remove button. It handles removal asking
         * user if associated patients should be deleted. 
         */
        [CCode (instance_pos = -1)]
        public void on_remove_button_clicked (Button button) {
 			view.remove_selected_doctor ();
        }
    }
    
}
