/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 *            Gianmarco Brocchi <brocchi@poisson.phc.unipi.it>
 */
 
 using Gee;
 using Sqlite;
 
 namespace Clinica {
 
    public class VisitIterator : SqlDataIterator {

        public VisitIterator () {
            base (Application.resources.db, Visit.table);
            db.prepare (@"SELECT ID FROM $(Visit.table) ORDER by date DESC;", -1, out stmt, null);
        }
        public new VisitIterator iterator () { return this; }
        public new Visit get () { 
            return new Visit.with_id (base.get ()); 
        }
    }
 
    public class Visit : SqlDataType {
    
        public static new string table;
        
        /* FIELDS */
        public string anamnesis {
        	get { return get_text ("anamnesis"); }
        	set { set_text ("anamnesis", value); }
        }
        
        public string physical_examination {
        	get { return get_text ("physical_examination"); }
        	set { set_text ("physical_examination", value); }
        }
        
        public string laboratory_exam {
        	get { return get_text ("laboratory_exam"); }
        	set { set_text ("laboratory_exam", value); }
        }
        
        public string histopathology {
        	get { return get_text ("histopathology"); }
        	set { set_text ("histopathology", value); }
        }
        
        public string diagnosis {
        	get { return get_text ("diagnosis"); }
        	set { set_text ("diagnosis", value); }
        }
        
        public string topical_therapy {
        	get { return get_text ("topical_therapy"); }
        	set { set_text ("topical_therapy", value); }
        }
        
        public string systemic_therapy {
        	get { return get_text ("systemic_therapy"); }
        	set { set_text ("systemic_therapy", value); }
        }
        
        public string subsequent_checks {
        	get { return get_text ("subsequent_checks"); }
        	set { set_text ("subsequent_checks", value); }
        }
        
        private DateTime _date;
        public DateTime date {
        	get { 
        		_date = get_date ("date");
        		return _date;
        	}
        	set {
        		_date = value;
        		set_date ("date", _date);
        	}
        }
        
        private Patient _patient;
        public  Patient patient {
        	get {
        		_patient = new Patient.with_id (get_integer ("patient"));
        		return _patient;
        	}
        	set {
        		this._patient = value;
        		set_integer("patient", value.get_id ());
        	}
        }
        
        /**
         * @brief Create a new visit to 
         * the passed patient.
         * @param patient The patient that has been
         * visited
         */
        public Visit (Patient? patient) {
            base (Application.resources.db);
            table_name = table;
            error.connect ((t,l) => Application.resources.error_callback(t,l));
            table_name = "visits";
            
            add_text_field ("anamnesis");
            add_text_field ("physical_examination");
            add_text_field ("laboratory_exam");
            add_text_field ("histopathology");
            add_text_field ("diagnosis");
            add_text_field ("topical_therapy");
            add_text_field ("systemic_therapy");
            add_text_field ("subsequent_checks");
            add_date_field ("date");
            
            add_integer_field ("patient");
            
            if (patient != null) {
                this.patient = patient;
            }
            
            init_resources ();
        }
        
        public Visit.with_id (int ID) {
            this (null);
            load (ID);
            this.patient = new Patient.with_id (get_integer ("patient"));
        }
        
        public static new VisitIterator all () {
            return new VisitIterator ();
        }
       
    }
 
 
 }
