/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 *            Gianmarco Brocchi <brocchi@poisson.phc.unipi.it>
 */

using Gtk;

namespace Clinica {

	public class VisitActions : Alignment {
	
		/* Buttons */
		private Button show_details_button;
		private Button save_button;
	
		/* Signals */
		public signal void save_visit();
		public signal void show_details();
	
		public VisitActions () {
			GLib.Object (xalign: 0.5F, yalign: 0F, xscale: 1F, yscale: 0F);
			
			/* Create an HBox to hold the buttons */
			var hbox = new HBox (false, 6);
			
			/* Show more details on this patient */
			show_details_button = new Button.with_label ("");
			show_details_button.clicked.connect ((button) => show_details ());
			hbox.pack_start (show_details_button);
		
			/* The save button */
			save_button = new Button.from_stock (Gtk.Stock.SAVE);
			save_button.clicked.connect ((button) => save_visit ());
			hbox.pack_start (save_button);
			
			add (hbox);
		}
		
		public void set_details_button_mode (VisitToolbar.ViewMode mode) {
			if (mode == VisitToolbar.ViewMode.SHORT) {
				(show_details_button.get_child () as Label).set_text (_("Show details of patient"));
			}
			else {
				(show_details_button.get_child () as Label).set_text (_("Hide details of patient"));
			}
		}
	}
	
}
