/*
 *   This file is part of Clinica.
 *
 *   Clinica is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Clinica is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Clinica.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Authors: Leonardo Robol <leo@robol.it>
 *            Gianmarco Brocchi <brocchi@poisson.phc.unipi.it>
 */

using Gtk;

namespace Clinica {
	
	public class VisitBrowser : Notebook {
		
		private Patient patient;
		private VisitTab new_page;
		private VisitListStore store;
		
		ulong new_tab_saved_connection_id;
		
		/**
		 * @brief Browser for the Visits of a Patient
		 */
		public VisitBrowser (Patient p) {
			
			/* Set Tab on the left */
			set_tab_pos (PositionType.LEFT);
			
			/* Get the visit store */
			store = Application.resources.visit_list_store;
			
			patient = p;
			
			/*  First add a new visit and keep a reference to new_page
			 *  to focus it on page loading. */
			var l = new Label(_("New visit"));
			new_page = new VisitTab.with_patient (patient, l);
			append_page (new_page, l);
			
			new_tab_saved_connection_id = new_page.saved.connect (on_new_page_saved);
				
			/* And then load all visits for the patient */
			Visit v;
			foreach(TreeIter it in store.get_visits_of (p)) {
				v = store.iter_to_visit (it);
				l = new Label(v.date.format ("%F"));
				append_page (new VisitTab (v, l), l);
			}
		}
		
		public void save_focused_visit () {
			int page_id = get_current_page();
			VisitTab tab = get_nth_page (page_id) as VisitTab;
			tab.save_visit ();
		}
		
		/**
		 * @brief Callback called when the new page is saved
		 * that adds a new "new page".
		 */
		private void on_new_page_saved (VisitTab tab) {
			/* First disconnect the signal so we won't be called
			 * again */
			tab.disconnect (new_tab_saved_connection_id);
			
			/* Create a new one and connect it */
			var l = new Label(_("New visit"));
			new_page = new VisitTab.with_patient (patient, l);
			prepend_page (new_page, l);
			new_page.show_all();
			
			new_tab_saved_connection_id = new_page.saved.connect (on_new_page_saved);
		}
		
		/**
		 * @brief Focus the first widget on the visittab so the user
		 * can start editing. 
		 */
		public void focus_new_page () {
			new_page.grab_focus ();
		}
	}
	
}
